# ProjectWithChildren

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**logo** | **str** |  | [optional] [readonly] 
**name** | **str** | Name of the project | 
**status** | **str** |  | [optional] 
**created_at** | **datetime** | Creation date | [optional] [readonly] 
**updated_at** | **datetime** | Date of the last update | [optional] [readonly] 
**parent_id** | **int** |  | [optional] 
**children** | [**list[ProjectWithChildren]**](ProjectWithChildren.md) |  | [optional] [readonly] 
**root_folder_id** | **str** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


